@@ -2,10 +2,11 @@ from __future__ import annotations
 
 import re
 import os
-from typing import List
+from typing import List, Optional
 
 from python_search.apps.notification_ui import send_notification
 from python_search.configuration.configuration import PythonSearchConfiguration
+from python_search.configuration.loader import ConfigurationLoader
 from python_search.context import Context
 from python_search.core_entities import Key
 from python_search.events.run_performed import RunPerformed
@@ -18,7 +19,6 @@ from python_search.search_ui.serialized_entry import (
     decode_serialized_data_from_entry_text,
 )
 
-logger = setup_run_key_logger()
 
 
 class EntryRunner:
@@ -26,8 +26,11 @@ class EntryRunner:
     Responsible to execute the _entries matched
     """
 
-    def __init__(self, configuration: PythonSearchConfiguration):
+    def __init__(self, configuration: Optional[PythonSearchConfiguration] = None):
+        if not configuration:
+            configuration = ConfigurationLoader().load_config()
         self.configuration = configuration
+        self.logger = setup_run_key_logger()
 
     @notify_exception()
     def run(
@@ -50,15 +53,15 @@ class EntryRunner:
 
         key = str(Key.from_fzf(entry_text))
 
-        logger.info("Arrived at run key")
+        self.logger.info("Arrived at run key")
         # if there are : in the line just take all before it as it is
         # usually the key from fzf, and our keys do not accept :
 
         if from_shortcut:
             send_notification(f"{key}")
 
-        metadata = decode_serialized_data_from_entry_text(entry_text, logger)
-        logger.info(f"Decoded metadata {metadata}")
+        metadata = decode_serialized_data_from_entry_text(entry_text, self.logger)
+        self.logger.info(f"Decoded metadata {metadata}")
         rank_position = metadata.get("position")
 
         # when there are no matches we actually will use the query and interpret it
@@ -71,7 +74,7 @@ class EntryRunner:
         if not matches:
             raise Exception(f"No key matches you given requested key: {key}")
 
-        logger.info(
+        self.logger.info(
             f"""
             Matches of key: {key}
             matches: {matches}
@@ -94,7 +97,7 @@ class EntryRunner:
         result = InterpreterMatcher.build_instance(self.configuration).default(key)
 
 
-        logger.info("Passed interpreter")
+        self.logger.info("Passed interpreter")
         run_performed = RunPerformed(
             key=key,
             query_input=query_used,
@@ -102,7 +105,7 @@ class EntryRunner:
             rank_uuid=metadata.get("uuid"),
             rank_position=metadata.get("position"),
         )
-        logger.info(f"Run performed = {run_performed}")
+        self.logger.info(f"Run performed = {run_performed}")
         LogRunPerformedClient().send(run_performed)
 
         # this needs to be last as it will kill the process
@@ -125,7 +128,7 @@ class EntryRunner:
             encoded_registered_key = generate_identifier(registered_key)
             matches_kv_encoded = key_regex.search(encoded_registered_key)
             if matches_kv_encoded:
-                logger.info(f"{key} matches {encoded_registered_key}")
+                self.logger.info(f"{key} matches {encoded_registered_key}")
                 matching_keys.append(registered_key)
 
         return matching_keys
@@ -139,3 +142,12 @@ def generate_identifier(string):
     result = result.lower()
 
     return result
+
+
+def main():
+    """
+    Entry point to run a key
+    """
+    import fire
+
+    fire.Fire(EntryRunner().run)
